ReleasePackerCommandStatus enum

The status of a ReleasePackerCommand execution.

Inheritance
Available extensions

Values

ok → const ReleasePackerCommandStatus

The command was executed successfully.

ignored → const ReleasePackerCommandStatus

The command was not applicable in the current context and was skipped. NOT an error: it does not abort the build.

error → const ReleasePackerCommandStatus

The command failed: it aborts the build.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isError bool
no setter
isIgnored bool
no setter
isOK bool
no setter
isSuccessful bool
true if it does NOT abort the build (ok or ignored).
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ReleasePackerCommandStatus>
A constant List of the values in this enum, in order of their declaration.