spawnPeriodicUpdateCheckerIsolate method
Spawns an Isolate with a periodic call to checkForUpdate.
-
onNewReleaseis called when the Isolate notifies that a new release is available. -
intervalis the Timer interval. Default: 1min. -
The created Isolate is shared by all calls to spawnPeriodicUpdateCheckerIsolate.
Implementation
Future<bool> spawnPeriodicUpdateCheckerIsolate(
OnRelease onNewRelease, {
Duration? interval,
Release? currentRelease,
}) => _PeriodicUpdateCheckerController.sendTask(
this,
onNewRelease,
interval,
currentRelease,
);